console.log("Defining NokNok");

NokNok = {AppSDK2: {}, AppSDK: {}}

/**
* NokNok.AppSDK2
*/
NokNok.AppSDK2.operation_REG = 'REG';
NokNok.AppSDK2.operation_AUTH = 'AUTH';
NokNok.AppSDK2.operation_OOB_AUTH = 'OOB_AUTH';
NokNok.AppSDK2.operation_DELETE_REG = 'DELETE_REG';

 /**
 * Initialize the App SDK for a particular operation.
 *
 * @param op The operation for which the initialization should be done.
 * @param rpData The information which should be provided by RP.
 *
 * @return ResponseData with initialization response
 */
NokNok.AppSDK2.initOperation = function (operation, rpData, onReply) {
    var strRpData = NokNok.serializeObject(rpData);
    console.log('NokNok.AppSDK2.initOperation = : ' +operation);

    NNLAppSdk.initOperation(
        operation,
        strRpData,
        NokNok.serializeFunction(onReply));
}

/**
* 
* Asynchronous function for processing request from server.
*
* @param rpData A pointer of RPData class instance with request parameters provided by RP.
* @param serverMessage The base64url encoded message from server.
*/
NokNok.AppSDK2.process = function (rpData, serverMessage, onReply) {
	console.log('NokNok.AppSDK2.process serverMessage = : '+ serverMessage);
	var strRpData = NokNok.serializeObject(rpData);
	NNLAppSdk.process(
		strRpData,
		serverMessage,
		NokNok.serializeFunction(onReply));
}

/**
 * Deletes the sessionID cookie.
 */
NokNok.AppSDK2.deleteSession = function() {
    NNLAppSdk.deleteSession();
}

NokNok.AppSDK2.getErrorText = function (status) {
    var errorText;
    switch (status) {
        case 0:
            errorText = "The operation completed successfully";
        break;
        case 1:
            errorText = "The operation failed for some nonspecific reason.";
        break;
        case 2:
            errorText = "The operation was canceled by user.";
        break;
        case 3:
            errorText = "No matching authentication method is found to process the request.";
        break;
        case 4:
            errorText = "The origin URL does not match the server URL, and it is not found in the manifest at the relying party.";
        break;
        case 5:
            errorText = "MFAC is not installed.";
        break;
        case 6:
            errorText = "The installed version of MFAC is not compatible.";
        break;
        case 7:
            errorText = "This application is not listed in the facet file at the relying party.";
        break;
        case 8:
            errorText = "The update transaction button was pressed.";
        break;
        case 9:
            errorText = "The transaction text could not be processed, e.g., certain HTML tags are not allowed.";
        break;
        case 10:
            errorText = "TSI Block cannot be verified.";
        break;
        case 11:
            errorText = "Waiting on user action to proceed.";
        break;
        case 12:
            errorText = "Window.location.protocol is not https.";
        break;
        case 13:
            errorText = "A violation of the UAF Protocol occurred.";
        break;
        default:
            errorText = "Unknown error code";
        break;
    }
    return errorText;
}

/**
* NokNok.AppSDK
*/
	NokNok.AppSDK.process = function (uafRequest, onReply) {
		var strFidoIn = NokNok.serializeObject({"uafIntent":"UAF_OPERATION","fidoRequest":uafRequest});
		console.log('NokNok.AppSDK.process fidoIn = : '+strFidoIn);

		NNLAppSdk.process(
			strFidoIn,
			NokNok.serializeFunction(onReply));

	}

	NokNok.AppSDK.notifyResponse = function (regId, onReply) {
		console.log('NokNok.AppSDK.notifyResponse regId = : '+regId);

		NNLAppSdk.notifyResponse(
			regId,
			NokNok.serializeFunction(onReply));
	}

/**
* NokNok
*/
NokNok.serializeObject = function (obj) {
	return ( (typeof (obj) === "undefined") || (obj == null) )? null: JSON.stringify(obj);
}

NokNok.serializeFunction = function (func) {
	NokNok.OnReply = ( (typeof (func) === "function")? (func) : (function (){}) );
	return "NokNok.OnReply";
}
